OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Невірний пароль",
    "The new password can not be the same as the previous one" : "Новий пароль не може бути таким самим, як і попередній",
    "No user supplied" : "Користувача не вказано",
    "Authentication error" : "Помилка автентифікації",
    "Wrong admin recovery password. Please check the password and try again." : "Невірний пароль відновлення адміністратора.  Будь ласка, перевірте пароль та спробуйте ще раз.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Backend не підтримує зміну паролів, але користувацький ключ шифрування було успішно змінено",
    "Unable to change password" : "Неможливо змінити пароль",
    "Couldn't send reset email. Please contact your administrator." : "Не можу надіслати email для скидання. Будь ласка, зверніться до вашого адміністратора.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "встановлення та оновлення додатків через магазин додатків або Об’єднання хмарних сховищ",
    "Federated Cloud Sharing" : "Об’єднання хмарних сховищ",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL використовує застарілу версію %s (%s). Будь ласка, поновіть вашу операційну систему або функції, такі як %s не працюватимуть надійно.",
    "A problem occurred, please check your log files (Error: %s)" : "Виникла проблема, будь ласка, перевірте свої файли журналів (Помилка: %s)",
    "Migration Completed" : "Міграцію завершено",
    "Group already exists." : "Група вже існує.",
    "Unable to add group." : "Неможливо додати групу.",
    "Unable to delete group." : "Неможливо видалити групу.",
    "log-level out of allowed range" : "рівень протоколювання перевищує дозволені межі",
    "Saved" : "Збережено",
    "test email settings" : "тест налаштувань електронної пошти",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Під час надсилання email сталася помилка. Будь ласка перевірте налаштування. (Помилка: %s)",
    "Email sent" : "Лист надіслано",
    "You need to set your user email before being able to send test emails." : "Перед надсиланням тестових листів ви повинні вказати свою email адресу.",
    "Invalid mail address" : "Неправильна email адреса",
    "A user with that name already exists." : "Користувач з таким іменем вже існує.",
    "Unable to create user." : "Неможливо створити користувача.",
    "Your %s account was created" : "Ваш %s аккаунт створений",
    "Unable to delete user." : "Неможливо видалити користувача.",
    "Forbidden" : "Заборонено",
    "Invalid user" : "Неправильний користувач",
    "Unable to change mail address" : "Неможливо поміняти email адресу",
    "Your full name has been changed." : "Ваше повне ім'я було змінено",
    "Unable to change full name" : "Неможливо змінити повне ім'я",
    "Redis" : "Redis",
    "__language_name__" : "__language_name__",
    "Language changed" : "Мову змінено",
    "Invalid request" : "Некоректний запит",
    "Admins can't remove themself from the admin group" : "Адміністратор не може видалити себе з групи адміністраторів",
    "Unknown user" : "Невідомий користувач",
    "Couldn't remove app." : "Неможливо видалити додаток.",
    "Official" : "Офіційні",
    "Approved" : "Схвалені",
    "All" : "Всі",
    "Enabled" : "Увімкнено",
    "Not enabled" : "Вимкнено",
    "No apps found for your version" : "Немає застосунків для вашої версії",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Офіційні додатки розроблені спільнотою ownCloud. Вони реалізують основні можливості ownCloud і готові до використання в продакшені.",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Схвалені додатки розроблені довіреними розробниками і пройшли незалежну перевірку безпеки. Їх активно супроводжують у репозиторії з відкритим кодом, а їх розробники стежать, щоб вони були стабільні й прийнятні для повсякденного використання.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Ця програма не перевірена на вразливості безпеки і є новою або нестабільною. Встановлюйте її на власний ризик.",
    "Please wait...." : "Зачекайте, будь ласка...",
    "Error while disabling app" : "Помилка вимикання додатка",
    "Disable" : "Вимкнути",
    "Enable" : "Увімкнути",
    "Error while enabling app" : "Помилка вмикання додатка",
    "Updating...." : "Оновлюється...",
    "Error while updating app" : "Помилка при оновленні додатку",
    "Updated" : "Оновлено",
    "Uninstalling ...." : "Видалення...",
    "Error while uninstalling app" : "Помилка видалення додатка",
    "Uninstall" : "Видалити",
    "App update" : "Оновлення додатку",
    "Experimental" : "Експериментальні",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Ви дійсно бажаєте додати \"{domain}\" як довірений домен?",
    "Add trusted domain" : "Додати довірений домен",
    "Migration in progress. Please wait until the migration is finished" : "Міграція триває. Будь ласка, зачекайте доки процес міграції завершиться",
    "Migration started …" : "Міграцію розпочато ...",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Виникла помилка. Будь ласка вивантажте PEM сертифікат в ASCII-кодуванні.",
    "Valid until {date}" : "Дійсно до {date}",
    "Delete" : "Видалити",
    "Sending..." : "Надсилання...",
    "An error occurred: {message}" : "Сталася помилка: {message}",
    "Select a profile picture" : "Обрати зображення облікового запису",
    "Very weak password" : "Дуже слабкий пароль",
    "Weak password" : "Слабкий пароль",
    "So-so password" : "Такий собі пароль",
    "Good password" : "Добрий пароль",
    "Strong password" : "Надійний пароль",
    "Groups" : "Групи",
    "Unable to delete {objName}" : "Не вдалося видалити {objName}",
    "A valid group name must be provided" : "Потрібно задати вірне ім'я групи",
    "deleted {groupName}" : "видалено {groupName}",
    "undo" : "відмінити",
    "never" : "ніколи",
    "deleted {userName}" : "видалено {userName}",
    "add group" : "додати групу",
    "enabled" : "увімкнено",
    "disabled" : "вимкнено",
    "no group" : "без групи",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Зміна пароля призведе до втрати даних, тому що відновлення даних не доступно для цього користувача",
    "A valid username must be provided" : "Потрібно задати вірне ім'я користувача",
    "A valid password must be provided" : "Потрібно задати вірний пароль",
    "A valid email must be provided" : "Вкажіть дійсний email",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Агов,<br><br>просто щоб ви знали, у вас є аккаунт %s.<br><br>Ваше ім'я користувача: %s<br>Перейдіть сюди: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "Будьмо!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Агов,\n\nпросто щоб ви знали, у вас є аккаунт %s.\n\nВаше ім'я користувача: %s\nПерейдіть сюди: %s\n\n",
    "User documentation" : "Користувацька документація",
    "Administrator documentation" : "Документація адміністратора",
    "Online documentation" : "Документація онлайн",
    "Forum" : "Форум",
    "Issue tracker" : "Вирішення проблем",
    "Commercial support" : "Комерційна підтримка",
    "Developer documentation" : "Документація для розробників",
    "Documentation:" : "Документація:",
    "Admin documentation" : "Документація адміністратора",
    "Report a bug" : "Повідомити про помилку",
    "Show description …" : "Показати деталі ...",
    "Hide description …" : "Сховати деталі ...",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ця програма не може бути встановлено, так як наступні залежності не будуть виконані:",
    "Enable only for specific groups" : "Включити тільки для конкретних груп",
    "Uninstall App" : "Видалити додаток",
    "Cron" : "Планувальник Cron",
    "Last cron job execution: %s." : "Останнє виконане Cron завдання: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Останнє виконане Cron завдання: %s. Щось здається неправильним.",
    "Cron was not executed yet!" : "Cron-задачі ще не запускалися!",
    "Open documentation" : "Відкрити документацію",
    "Execute one task with each page loaded" : "Виконати одне завдання для кожної завантаженої сторінки ",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php зареєстрований в службі webcron та буде викликатися кожні 15 хвилин через HTTP.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Використовувати системний cron для виклику cron.php кожні 15 хвилин.",
    "Common Name" : "Ім'я:",
    "Valid until" : "Дійсно до",
    "Issued By" : "Виданий",
    "Valid until %s" : "Дійсно до %s",
    "Import root certificate" : "Імпортувати кореневий сертифікат",
    "Server-side encryption" : "Шифрування на сервері",
    "Enable server-side encryption" : "Увімкнути шифрування на сервері",
    "Please read carefully before activating server-side encryption: " : "Будьте обережні під час активування шифрування на сервері:",
    "Enable encryption" : "Увімкнути шифрування",
    "Select default encryption module:" : "Обрати модуль шифрування за замовчуванням:",
    "Start migration" : "Розпочати міграцію",
    "Sharing" : "Спільний доступ",
    "Allow apps to use the Share API" : "Дозволити програмам використовувати API спільного доступу",
    "Allow users to share via link" : "Дозволити користувачам ділитися через посилання",
    "Allow public uploads" : "Дозволити публічне завантаження",
    "Enforce password protection" : "Захист паролем обов'язковий",
    "Set default expiration date" : "Встановити термін дії за замовчуванням",
    "Allow users to send mail notification for shared files" : "Дозволити користувачам сповіщати листами про спільний доступ до файлів",
    "Expire after " : "Скінчиться через",
    "days" : "днів",
    "Enforce expiration date" : "Термін дії обов'язковий",
    "Allow resharing" : "Дозволити перевідкривати спільний доступ",
    "Restrict users to only share with users in their groups" : "Дозволити користувачам відкривати спільний доступ лише для користувачів з їхньої групи",
    "Allow users to send mail notification for shared files to other users" : "Дозволити користувачам сповіщати листами про спільний доступ до файлів",
    "Exclude groups from sharing" : "Виключити групи зі спільного доступу",
    "These groups will still be able to receive shares, but not to initiate them." : "Ці групи зможуть отримувати спільні файли, але не зможуть відправляти їх.",
    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Дозволи автодоповнення імені користувача в діалозі спільного доступу. Якщо вимкнено - треба буде вводити повне ім’я користувача.",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Усі (критичні проблеми, помилки, попередження, інформаційні, налагодження)",
    "Info, warnings, errors and fatal issues" : "Інформаційні, попередження, помилки та критичні проблеми",
    "Warnings, errors and fatal issues" : "Попередження, помилки та критичні проблеми",
    "Errors and fatal issues" : "Помилки та критичні проблеми",
    "Fatal issues only" : "Тільки критичні проблеми",
    "Log" : "Журнал",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Файл журналу - більше 100 МБ. Його завантаження може зайняти деякий час!",
    "None" : "Жоден",
    "Login" : "Логін",
    "Plain" : "Звичайний",
    "NT LAN Manager" : "Менеджер NT LAN",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Сервер електронної пошти",
    "This is used for sending out notifications." : "Використовується для відсилання повідомлень.",
    "Send mode" : "Режим надсилання",
    "Encryption" : "Шифрування",
    "From address" : "Адреса відправника",
    "mail" : "пошта",
    "Authentication method" : "Спосіб аутентифікації",
    "Authentication required" : "Потрібна аутентифікація",
    "Server address" : "Адреса сервера",
    "Port" : "Порт",
    "Credentials" : "Облікові дані",
    "SMTP Username" : "Ім'я користувача SMTP",
    "SMTP Password" : "Пароль SMTP",
    "Store credentials" : "Зберігати облікові дані",
    "Test email settings" : "Тестувати налаштування електронної пошти",
    "Send email" : "Надіслати листа",
    "Security & setup warnings" : "Попередження безпеки та налаштування",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Тільки перегляд був включений. Це запобігає встановити деякі конфігурації через веб-інтерфейс. Крім того, файл повинен бути доступний для запису вручну для кожного оновлення.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "Схоже, що PHP налаштовано на вичищення блоків вбудованої документації. Це зробить кілька основних додатків недоступними.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Це, ймовірно, обумовлено використанням кеша/прискорювача такого як Zend OPcache або eAccelerator.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP модуль 'fileinfo' відсутній. Ми наполегливо рекомендуємо увімкнути цей модуль, щоб отримати кращі результати при виявленні MIME-типів.",
    "System locale can not be set to a one which supports UTF-8." : "Неможливо встановити системну локаль, яка б підтримувала UTF-8.",
    "This means that there might be problems with certain characters in file names." : "Це означає, що можуть виникати проблеми з деякими символами в іменах файлів.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Пропонуємо встановити необхідні пакети для вашої системи для підтримки однієї з наступних мов %s.",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Якщо ваша копія ownCloud встановлена не в корені домену та використовує систему планування CRON, можливі проблеми з генерацією правильних URL. Щоб уникнути цього, встановіть опцію \"overwrite.cli.url\" файлу config.php відповідно до теки розташування установки (Ймовірніше за все, це \"%s\")",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "В якості бази даних використовується SQLite. Для великих установок ми рекомендуємо перейти на інший тип серверу баз даних.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Особливо сумнівне використання SQLite при синхронізації файлів з використанням клієнта для ПК.",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Не вдалося запустити завдання планувальника через CLI. Відбулися наступні технічні помилки:",
    "All checks passed." : "Всі перевірки пройдено.",
    "Tips & tricks" : "Поради і трюки",
    "How to do backups" : "Як робити резервне копіювання",
    "Advanced monitoring" : "Розширений моніторинг",
    "Performance tuning" : "Налаштування продуктивності",
    "Improving the config.php" : "Покращення  config.php",
    "Theming" : "Оформлення",
    "Hardening and security guidance" : "Інструктування з безпеки та захисту",
    "Get the apps to sync your files" : "Отримати додатки для синхронізації ваших файлів",
    "Desktop client" : "Клієнт для ПК",
    "Android app" : "Android-додаток",
    "iOS app" : "iOS додаток",
    "Show First Run Wizard again" : "Показувати Майстер Налаштувань знову",
    "Profile picture" : "Зображення облікового запису",
    "Upload new" : "Завантажити нове",
    "Remove image" : "Видалити зображення",
    "Cancel" : "Відмінити",
    "Choose as profile picture" : "Обрати як зображення для профілю",
    "Full name" : "Повне ім'я",
    "No display name set" : "Коротке ім'я не вказано",
    "Email" : "E-mail",
    "Your email address" : "Ваша адреса електронної пошти",
    "No email address set" : "E-mail не вказано",
    "You are member of the following groups:" : "Ви є членом наступних груп:",
    "Password" : "Пароль",
    "Unable to change your password" : "Не вдалося змінити Ваш пароль",
    "Current password" : "Поточний пароль",
    "New password" : "Новий пароль",
    "Change password" : "Змінити пароль",
    "Language" : "Мова",
    "Help translate" : "Допомогти з перекладом",
    "Unlimited" : "Необмежено",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Розроблено {communityopen} спільнотою ownCloud {linkclose}, {githubopen} вихідний код {linkclose} ліцензується відповідно до {licenseopen} <abbr title = \"Публічної ліцензії Affero General\"> AGPL </ abbr> {linkclose}.",
    "Name" : "Ім’я",
    "Username" : "Ім'я користувача",
    "Done" : "Готово",
    "Version" : "Версія",
    "Personal" : "Особисте",
    "Admin" : "Адмін",
    "Error" : "Помилка",
    "Show storage location" : "Показати місцезнаходження сховища",
    "Show last log in" : "Показати останній вхід в систему",
    "Show user backend" : "Показати користувача",
    "Send email to new user" : "Надіслати email новому користувачу",
    "Show email address" : "Показати адресу електронної пошти",
    "E-Mail" : "Адреса електронної пошти",
    "Create" : "Створити",
    "Admin Recovery Password" : "Пароль адміністратора для відновлення",
    "Enter the recovery password in order to recover the users files during password change" : "Введіть пароль для того, щоб відновити файли користувачів при зміні паролю",
    "Add Group" : "Додати групу",
    "Group" : "Група",
    "Everyone" : "Всі",
    "Admins" : "Адміністратори",
    "Default Quota" : "Квота за замовчуванням",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Будь ласка, вкажіть розмір сховища (наприклад: \"512 MB\" або \"12 GB\")",
    "Other" : "Інше",
    "Full Name" : "Повне Ім'я",
    "Group Admin for" : "Адміністратор групи",
    "Quota" : "Квота",
    "Storage Location" : "Місцезнаходження сховища",
    "User Backend" : "Внутрішній користувач",
    "Last Login" : "Останній вхід",
    "change full name" : "змінити ім'я",
    "set new password" : "встановити новий пароль",
    "change email address" : "Змінити адресу електронної пошти",
    "Default" : "За замовчуванням",
    "Share" : "Поділитися",
    "What to log" : "Що зберігати в протокол",
    "Add" : "Додати",
    "Download logfile (%s)" : "Завантажити протокол (%s)",
    "%s password changed successfully" : "%s пароль змінено успішно",
    "Change" : "Змінити",
    "Invalid email address" : "Хибна адреса ел. пошти",
    "Owner language" : "Мова власника",
    "Wrong current password" : "Хибний поточний пароль",
    "The new password cannot be the same as the previous one" : "Новий пароль не може бути таким самим як і попередній"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
